#include "MotionCommand.h"
#include "Events/EventTranslator.h"
#include "Events/EventRouter.h"
#include <iostream>

using namespace std;

void MotionCommand::postEvent(const EventBase& event) {
	if(queue==NULL) {
		erouter->postEvent(event);
	} else {
		queue->encodeEvent(event);
	}
}



/*! @file
 * @brief Empty
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-3_0 $
 * $Revision: 1.5 $
 * $State: Exp $
 * $Date: 2006/09/11 23:05:11 $
 */

